Fix 'succeded' typo to 'succeeded'

Looks like this got copied and pasted into almost all the update
scripts.

BUG=none
TEST=none

Change-Id: I46d8e8d952cef6e479f8919cb6c190188489336b
Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/platform/touch_updater/+/2796157
Tested-by: Harry Cutts <hcutts@chromium.org>
Auto-Submit: Harry Cutts <hcutts@chromium.org>
Commit-Queue: Harry Cutts <hcutts@chromium.org>
Reviewed-by: Sean O'Brien <seobrien@chromium.org>
diff --git a/host_scripts/update_new_firmware_version.sh b/host_scripts/update_new_firmware_version.sh
index 106eae5..7c43af0 100755
--- a/host_scripts/update_new_firmware_version.sh
+++ b/host_scripts/update_new_firmware_version.sh
@@ -626,7 +626,7 @@
 # 1. build chromeos-touch-firmware-"${FLAGS_board}"
 # 2. install this package into the DUT by cros deploy.
 # 3. reboot the DUT
-# 4. Extract logs from DUT and verify the keyword - "Update FW succeded"
+# 4. Extract logs from DUT and verify the keyword - "Update FW succeeded"
 #
 # This function works on the folder contained the ebuild file in order to call
 # emerge command to build the package.
diff --git a/scripts/chromeos-cyapa-touch-firmware-update-legacy.sh b/scripts/chromeos-cyapa-touch-firmware-update-legacy.sh
index fa9c200..1aa51cb 100644
--- a/scripts/chromeos-cyapa-touch-firmware-update-legacy.sh
+++ b/scripts/chromeos-cyapa-touch-firmware-update-legacy.sh
@@ -131,7 +131,7 @@
         "${fw_version}"
       die "Firmware update failed. Current Firmware: ${active_fw_version}"
     fi
-    log_msg "Update FW succeded. Current Firmware: ${active_fw_version}"
+    log_msg "Update FW succeeded. Current Firmware: ${active_fw_version}"
     report_update_result "${device_path}" "${REPORT_RESULT_SUCCESS}" \
       "${active_fw_version}"
 
diff --git a/scripts/chromeos-elan-hid-touch-firmware-update-legacy.sh b/scripts/chromeos-elan-hid-touch-firmware-update-legacy.sh
index 337b7b9..af8164f 100644
--- a/scripts/chromeos-elan-hid-touch-firmware-update-legacy.sh
+++ b/scripts/chromeos-elan-hid-touch-firmware-update-legacy.sh
@@ -277,7 +277,7 @@
         "${fw_version}"
       die "Firmware update failed. Current Firmware: ${active_fw_ver}"
     fi
-    log_msg "Update FW succeded. Current Firmware: ${active_fw_ver}"
+    log_msg "Update FW succeeded. Current Firmware: ${active_fw_ver}"
     report_update_result "${FLAGS_device_path}" "${REPORT_RESULT_SUCCESS}" \
       "${active_fw_ver}"
 
diff --git a/scripts/chromeos-elan-touch-firmware-update-legacy.sh b/scripts/chromeos-elan-touch-firmware-update-legacy.sh
index f00470e..de2de2d 100644
--- a/scripts/chromeos-elan-touch-firmware-update-legacy.sh
+++ b/scripts/chromeos-elan-touch-firmware-update-legacy.sh
@@ -238,7 +238,7 @@
         "${fw_version}"
       die "Firmware update failed. Current Firmware: ${active_fw_version}"
     fi
-    log_msg "Update FW succeded. Current Firmware: ${active_fw_version}"
+    log_msg "Update FW succeeded. Current Firmware: ${active_fw_version}"
     report_update_result "${touch_device_path}" "${REPORT_RESULT_SUCCESS}" \
       "${active_fw_version}"
 
diff --git a/scripts/chromeos-emright-touch-firmware-update-legacy.sh b/scripts/chromeos-emright-touch-firmware-update-legacy.sh
index dec682d..395a97a 100644
--- a/scripts/chromeos-emright-touch-firmware-update-legacy.sh
+++ b/scripts/chromeos-emright-touch-firmware-update-legacy.sh
@@ -147,7 +147,7 @@
         "${fw_version}"
       die "Firmware update failed. Current Firmware: ${active_fw_version}"
     fi
-    log_msg "Update FW succeded. Current Firmware: ${active_fw_version}"
+    log_msg "Update FW succeeded. Current Firmware: ${active_fw_version}"
     report_update_result "${FLAGS_dev_i2c_path}" "${REPORT_RESULT_SUCCESS}" \
       "${active_fw_version}"
   fi
diff --git a/scripts/chromeos-g2touch-touch-firmware-update-legacy.sh b/scripts/chromeos-g2touch-touch-firmware-update-legacy.sh
index 4170b0f..4dcd96a 100755
--- a/scripts/chromeos-g2touch-touch-firmware-update-legacy.sh
+++ b/scripts/chromeos-g2touch-touch-firmware-update-legacy.sh
@@ -88,7 +88,7 @@
 
   # Show info for the exit-value of executing "updateFW"
   if [ "${ret}" -eq 0 ]; then
-    log_msg "UpdateFW succeded"
+    log_msg "UpdateFW succeeded"
   else
     # Some error occurred when executing "updateFW"
     log_msg "error: UpdateFW failed, code=${ret}"
@@ -189,7 +189,7 @@
 
   # Create g2touch hidraw
   g2touch_touch_hidraw="$(create_g2touch_hidraw)"
-  log_msg "Create node succeded: '${g2touch_touch_hidraw}'."
+  log_msg "Create node succeeded: '${g2touch_touch_hidraw}'."
 
   # Get device's fw version.
   active_fw_version="$(get_active_firmware_version "${g2touch_touch_hidraw}")"
@@ -219,7 +219,7 @@
 
     # Recreate hidraw. The /dev/hidrawX may be changed after device reset.
     g2touch_touch_hidraw="$(create_g2touch_hidraw)"
-    log_msg "Recreate node succeded: '${g2touch_touch_hidraw}'."
+    log_msg "Recreate node succeeded: '${g2touch_touch_hidraw}'."
 
     # Confirm that the FW was updated by checking the current FW version again
     active_fw_version="$(get_active_firmware_version "${g2touch_touch_hidraw}")"
@@ -231,7 +231,7 @@
       die "Firmware update failed. Current Firmware: ${active_fw_version}"
     fi
 
-    log_msg "Update FW succeded. Current Firmware: ${active_fw_version}"
+    log_msg "Update FW succeeded. Current Firmware: ${active_fw_version}"
     report_update_result "${FLAGS_device_path}" "${REPORT_RESULT_SUCCESS}" \
       "${active_fw_version}"
   fi
diff --git a/scripts/chromeos-google-touch-firmware-update-legacy.sh b/scripts/chromeos-google-touch-firmware-update-legacy.sh
index 41d02c5..f30df21 100755
--- a/scripts/chromeos-google-touch-firmware-update-legacy.sh
+++ b/scripts/chromeos-google-touch-firmware-update-legacy.sh
@@ -160,7 +160,7 @@
         "$(extract_numerical_fw_version "${updater_fw_ver}")"
       die "Firmware update failed. Current Firmware: ${active_fw_ver}"
     fi
-    log_msg "Update FW succeded. Current Firmware: ${active_fw_ver}"
+    log_msg "Update FW succeeded. Current Firmware: ${active_fw_ver}"
     report_update_result "${FLAGS_device_path}" "${REPORT_RESULT_SUCCESS}" \
       "$(extract_numerical_fw_version "${active_fw_ver}")"
 
diff --git a/scripts/chromeos-melfas-hid-touch-firmware-update-legacy.sh b/scripts/chromeos-melfas-hid-touch-firmware-update-legacy.sh
index 4a1a031..420a699 100644
--- a/scripts/chromeos-melfas-hid-touch-firmware-update-legacy.sh
+++ b/scripts/chromeos-melfas-hid-touch-firmware-update-legacy.sh
@@ -235,7 +235,7 @@
     if  [ "${update_type}" -ne "${UPDATE_NOT_NEEDED_UP_TO_DATE}" ]; then
       die "Firmware update failed. Current Firmware: ${active_fw_version}"
     fi
-    log_msg "Update FW succeded. Current Firmware: ${active_fw_version}"
+    log_msg "Update FW succeeded. Current Firmware: ${active_fw_version}"
   fi
 
   exit 0
diff --git a/scripts/chromeos-melfas-touch-firmware-update-legacy.sh b/scripts/chromeos-melfas-touch-firmware-update-legacy.sh
index db17380..93d3d70 100644
--- a/scripts/chromeos-melfas-touch-firmware-update-legacy.sh
+++ b/scripts/chromeos-melfas-touch-firmware-update-legacy.sh
@@ -112,7 +112,7 @@
         "${fw_version}"
       die "Firmware update failed. Current Firmware: ${active_fw_version}"
     fi
-    log_msg "Update FW succeded. Current Firmware: ${active_fw_version}"
+    log_msg "Update FW succeeded. Current Firmware: ${active_fw_version}"
     report_update_result "${touch_device_path}" "${REPORT_RESULT_SUCCESS}" \
       "${active_fw_version}"
 
diff --git a/scripts/chromeos-pixart-hid-touch-firmware-update-legacy.sh b/scripts/chromeos-pixart-hid-touch-firmware-update-legacy.sh
index 151a7e5..e2d9567 100644
--- a/scripts/chromeos-pixart-hid-touch-firmware-update-legacy.sh
+++ b/scripts/chromeos-pixart-hid-touch-firmware-update-legacy.sh
@@ -197,7 +197,7 @@
         "${fw_version}"
       die "[Pix TP]Firmware update failed. Current Firmware: ${active_fw_ver}"
     fi
-    log_msg "[Pix TP]Update FW succeded. Current Firmware: ${active_fw_ver}"
+    log_msg "[Pix TP]Update FW succeeded. Current Firmware: ${active_fw_ver}"
     report_update_result "${FLAGS_dev_i2c_path}" "${REPORT_RESULT_SUCCESS}" \
       "${active_fw_ver}"
     rebind_driver "${FLAGS_dev_i2c_path}"
diff --git a/scripts/chromeos-sis-touch-firmware-update-legacy.sh b/scripts/chromeos-sis-touch-firmware-update-legacy.sh
index 285e3fb..2b44a1a 100755
--- a/scripts/chromeos-sis-touch-firmware-update-legacy.sh
+++ b/scripts/chromeos-sis-touch-firmware-update-legacy.sh
@@ -81,7 +81,7 @@
 
   # Show info for the exit-value of ececuting "updateFW"
   if [ "${ret}" -eq "0" ]; then
-    log_msg "'updateFW' succeded"
+    log_msg "'updateFW' succeeded"
   else
     # Some error occurred when executing "updateFW"
     log_msg "error: 'updateFW' failed, code=${ret}"
@@ -198,7 +198,7 @@
 
   # Create sis hidraw
   sis_touch_hidraw="$(create_sis_hidraw)"
-  log_msg "Create node succeded: '${sis_touch_hidraw}'."
+  log_msg "Create node succeeded: '${sis_touch_hidraw}'."
 
   # Get device's fw version.
   active_fw_version="$(get_active_firmware_version ${sis_touch_hidraw})"
@@ -229,7 +229,7 @@
 
     # Recreate sis hidraw. The /dev/hidrawX may be changed after device reset.
     sis_touch_hidraw="$(create_sis_hidraw)"
-    log_msg "Recreate node succeded: '${sis_touch_hidraw}'."
+    log_msg "Recreate node succeeded: '${sis_touch_hidraw}'."
 
     # Confirm that the FW was updated by checking the current FW version again
     active_fw_version="$(get_active_firmware_version ${sis_touch_hidraw})"
@@ -241,7 +241,7 @@
       die "Firmware update failed. Current Firmware: ${active_fw_version}"
     fi
 
-    log_msg "Update FW succeded. Current Firmware: ${active_fw_version}"
+    log_msg "Update FW succeeded. Current Firmware: ${active_fw_version}"
     report_update_result "${FLAGS_device_path}" "${REPORT_RESULT_SUCCESS}" \
       "${active_fw_version}"
   fi
diff --git a/scripts/chromeos-synaptics-touch-firmware-update-legacy.sh b/scripts/chromeos-synaptics-touch-firmware-update-legacy.sh
index 46bd629..36969f5 100644
--- a/scripts/chromeos-synaptics-touch-firmware-update-legacy.sh
+++ b/scripts/chromeos-synaptics-touch-firmware-update-legacy.sh
@@ -154,7 +154,7 @@
         "${fw_version}"
       die "Firmware update failed. Current Firmware: ${active_fw_version}"
     fi
-    log_msg "Update FW succeded. Current Firmware: ${active_fw_version}"
+    log_msg "Update FW succeeded. Current Firmware: ${active_fw_version}"
     report_update_result "${FLAGS_i2c_path}" "${REPORT_RESULT_SUCCESS}" \
       "${active_fw_version}"
   fi
diff --git a/scripts/chromeos-wacom-touch-firmware-update-legacy.sh b/scripts/chromeos-wacom-touch-firmware-update-legacy.sh
index 0ad265b..d492279 100644
--- a/scripts/chromeos-wacom-touch-firmware-update-legacy.sh
+++ b/scripts/chromeos-wacom-touch-firmware-update-legacy.sh
@@ -257,7 +257,7 @@
         "${new_fw_ver}"
       die "Firmware update failed. Current Firmware: ${active_fw_ver}"
     fi
-    log_msg "Update FW succeded. Current Firmware: ${active_fw_ver}"
+    log_msg "Update FW succeeded. Current Firmware: ${active_fw_ver}"
     report_update_result "${FLAGS_device_path}" "${REPORT_RESULT_SUCCESS}" \
       "${active_fw_ver}"
 
diff --git a/scripts/chromeos-weida-hid-touch-firmware-update-legacy.sh b/scripts/chromeos-weida-hid-touch-firmware-update-legacy.sh
index 6c72669..617eb32 100644
--- a/scripts/chromeos-weida-hid-touch-firmware-update-legacy.sh
+++ b/scripts/chromeos-weida-hid-touch-firmware-update-legacy.sh
@@ -158,7 +158,7 @@
         "${fw_param_ver}"
       die "Firmware update failed. Current Firmware: ${active_fw_param_ver}"
     fi
-    log_msg "Update FW succeded. Current Firmware: ${active_fw_param_ver}"
+    log_msg "Update FW succeeded. Current Firmware: ${active_fw_param_ver}"
     report_update_result "${FLAGS_device_path}" "${REPORT_RESULT_SUCCESS}" \
       "${active_fw_param_ver}"
 
diff --git a/scripts/chromeos-weida-touch-firmware-update-legacy.sh b/scripts/chromeos-weida-touch-firmware-update-legacy.sh
index 5527bf9..14761f0 100644
--- a/scripts/chromeos-weida-touch-firmware-update-legacy.sh
+++ b/scripts/chromeos-weida-touch-firmware-update-legacy.sh
@@ -120,7 +120,7 @@
         "${fw_version}"
       die "Firmware update failed. Current Firmware: ${active_fw_version}"
     fi
-    log_msg "Update FW succeded. Current Firmware: ${active_fw_version}"
+    log_msg "Update FW succeeded. Current Firmware: ${active_fw_version}"
     report_update_result "${touch_device_path}" "${REPORT_RESULT_SUCCESS}" \
       "${active_fw_version}"
diff --git a/scripts/chromeos-atmel-touch-firmware-update-legacy.sh b/scripts/chromeos-atmel-touch-firmware-update-legacy.sh
index 3335637..df282fb 100644
--- a/scripts/chromeos-atmel-touch-firmware-update-legacy.sh
+++ b/scripts/chromeos-atmel-touch-firmware-update-legacy.sh
@@ -198,7 +198,7 @@
     set_fw_file "${touch_device_path}" "${fw_link_name}"
     standard_update_firmware "${touch_device_path}" "${fw_version_hexxed}"
 
     # Confirm that the update succeded, by re-reading the fw version
     active_fw_version="$(get_active_firmware_version "${touch_device_path}")"
     update_type="$(compare_fw_versions "${active_fw_version}" "${fw_version}")"
     if  [ "${update_type}" -ne "${UPDATE_NOT_NEEDED_UP_TO_DATE}" ]; then
@@ -206,7 +206,7 @@
         "${fw_version_hexxed}"
       die "Firmware update failed. Current Firmware: ${active_fw_version}"
     fi
-    log_msg "Update FW succeded. Current Firmware: ${active_fw_version}"
+    log_msg "Update FW succeeded. Current Firmware: ${active_fw_version}"
     report_update_result "${touch_device_path}" "${REPORT_RESULT_SUCCESS}" \
       "${active_fw_version}"
 
@@ -198,7 +198,7 @@
     standard_update_firmware "${touch_device_path}" "${fw_version_hexxed}"
 
-    # Confirm that the update succeded, by re-reading the fw version
+    # Confirm that the update succeeded, by re-reading the fw version
     active_fw_version="$(get_active_firmware_version "${touch_device_path}")"
     update_type="$(compare_fw_versions "${active_fw_version}" "${fw_version}")"
diff --git a/scripts/chromeos-raydium-touch-firmware-update-legacy.sh b/scripts/chromeos-raydium-touch-firmware-update-legacy.sh
index a803e5d..603ff4c 100755
--- a/scripts/chromeos-raydium-touch-firmware-update-legacy.sh
+++ b/scripts/chromeos-raydium-touch-firmware-update-legacy.sh
@@ -159,7 +159,7 @@
 
     for i in $(seq "${RAYDIUM_NUM_RETRIES}"); do
       standard_update_firmware "${touch_device_path}" "${fw_version}"
       # Confirm that the update succeded, by re-reading the fw version
       active_fw_version="$(get_active_firmware_version "${touch_device_path}")"
       update_type="$(compare_fw_versions "${active_fw_version}" "${fw_version}")"
       if  [ "${update_type}" -eq "${UPDATE_NOT_NEEDED_UP_TO_DATE}" ]; then
@@ -175,7 +175,7 @@
       fi
     done
 
-    log_msg "Update FW succeded. Current Firmware: ${active_fw_version}"
+    log_msg "Update FW succeeded. Current Firmware: ${active_fw_version}"
     report_update_result "${touch_device_path}" "${REPORT_RESULT_SUCCESS}" \
       "${active_fw_version}"
     rebind_driver "${touch_device_path}"
@@ -159,7 +159,7 @@
     for i in $(seq "${RAYDIUM_NUM_RETRIES}"); do
       standard_update_firmware "${touch_device_path}" "${fw_version}"
-      # Confirm that the update succeded, by re-reading the fw version
+      # Confirm that the update succeeded, by re-reading the fw version
       active_fw_version="$(get_active_firmware_version "${touch_device_path}")"
       update_type="$(compare_fw_versions "${active_fw_version}" "${fw_version}")"